@@ -11,213 +11,228 @@ use LWP;
 
 #the base class specifies the basic get/post/insert/update/delete methods
 
-our $VERSION  = 0.01_06;
+our $VERSION = 0.01_07;
 
-	sub __init {
-		my ($this,%params) = @_;
+sub __init {
+    my ( $this, %params ) = @_;
 
-		$this->{__NAMESPACES__}   = [ATOM_NAMESPACE];
-		$this->{__OVERRIDE__}     = FALSE;
-		$this->query(new WebService::GData::Query());
+    $this->{__NAMESPACES__} = [ATOM_NAMESPACE];
+    $this->{__OVERRIDE__}   = FALSE;
+    $this->{__AUTH__}       = undef;
+    $this->query( new WebService::GData::Query() );
 
+    $this->auth( $params{auth} )
+      if ( _is_auth_object_compliant( $params{auth} ) );
+}
 
-		$this->{Auth}   = $params{auth} if(_is_auth_object_compliant($params{auth}));	
-	}
+sub auth {
+    my ( $this, $auth ) = @_;
 
-	sub auth {
-		my ($this,$auth)=@_;
+    if ( _is_auth_object_compliant($auth) ) {
+        $this->{__AUTH__} = $auth;
 
-		if($auth && _is_auth_object_compliant($auth)) {
-			$this->{Auth} = $auth;
-			#done a _request with no authentification.
-			#update the ua agent string
-			$this->{ua}->agent(_create_ua_base_name().$auth->source()) if($this->{ua});
-		}
-		return $this->{Auth};
-	}
+        #done a request with no authentification.
+        #update the ua agent string
+        $this->{ua}->agent( _create_ua_base_name() . $auth->source() )
+          if ( $this->{ua} );
+    }
+    return $this->{__AUTH__};
+}
 
-	sub query {
-		my ($this,$query)=@_;
-		$this->{_basequery} = $query if($query && _is_query_object_compliant($query));
-		return $this->{_basequery};
-	}
+sub query {
+    my ( $this, $query ) = @_;
+    $this->{_basequery} = $query
+      if ( _is_query_object_compliant($query) );
+    return $this->{_basequery};
+}
 
-	sub override_method {
-		my ($this,$override) = @_;
+sub override_method {
+    my ( $this, $override ) = @_;
 
-		return $this->{__OVERRIDE__} if(!$override);
+    return $this->{__OVERRIDE__} if ( !$override );
 
-		if($override eq TRUE){
-			$this->{__OVERRIDE__}=TRUE;
-		}
-		if($override eq FALSE){
-			$this->{__OVERRIDE__}=FALSE;
-		}
-	}	
+    if ( $override eq TRUE ) {
+        $this->{__OVERRIDE__} = TRUE;
+    }
+    if ( $override eq FALSE ) {
+        $this->{__OVERRIDE__} = FALSE;
+    }
+}
 
-	#hacky for now, until I switch to JSONC where this won't be necessary anymore
-	sub get_namespaces {
-		my $this = shift;
-		return join (" ", @{$this->{__NAMESPACES__}});
-	}
+#hacky for now, until I switch to JSONC where this won't be necessary anymore
+sub get_namespaces {
+    my $this = shift;
+    return join( " ", @{ $this->{__NAMESPACES__} } );
+}
 
-	sub add_namespace {
-		my ($this,$namespace)= @_;
-		push @{$this->{__NAMESPACES__}},$namespace;
-	}
+sub add_namespace {
+    my ( $this, $namespace ) = @_;
+    push @{ $this->{__NAMESPACES__} }, $namespace;
+}
 
-	sub clean_namespace {
-		my ($this)= @_;
-		$this->{__NAMESPACES__}=[];
-	}
+sub clean_namespaces {
+    my ($this) = @_;
+    $this->{__NAMESPACES__} = [];
+}
 
-	sub get {
-		my ($this,$uri) = @_;
+sub get {
+    my ( $this, $uri ) = @_;
 
-		#the url from the feeds contain the version but not the one we pass directly
-		$uri= _delete_query_string($uri);
+    #the url from the feeds contain the version but not the one we pass directly
+    $uri = _delete_query_string($uri);
 
-    	my $req = HTTP::Request->new(GET => $uri.$this->query->to_query_string);
-  	       $req-> content_type('application/x-www-form-urlencoded');
+    my $req = HTTP::Request->new( GET => $uri . $this->query->to_query_string );
+    $req->content_type('application/x-www-form-urlencoded');
 
-		$this->_prepare__request($req);
-		
-		my $ret = $this->_request($req);
-		return $this->query->get('alt')=~m/json/ ? from_json($ret) : $ret;
+    $this->_prepare_request($req);
 
-	}
+    my $ret = $this->_request($req);
+    return $this->query->get('alt') =~ m/json/ ? from_json($ret) : $ret;
 
-	sub post {
-		my ($this,$uri,$content)    = @_;
-    	my $req = HTTP::Request->new(POST => $uri);
-  	       $req-> content_type('application/x-www-form-urlencoded');
-			$this->_prepare__request($req,length($content));
-           $req-> content($content);
-		return $this->_request($req);
-	}
+}
 
-	sub insert {
-		my ($this,$uri,$content,$callback) = @_;
-		return $this->_save('POST',$uri,$content,$callback);	
-	}
+sub post {
+    my ( $this, $uri, $content ) = @_;
+    my $req = HTTP::Request->new( POST => $uri );
+    $req->content_type('application/x-www-form-urlencoded');
+    $this->_prepare_request( $req, length($content) );
+    $req->content($content);
+    return $this->_request($req);
+}
 
-	sub update {
-		my ($this,$uri,$content,$callback) = @_;
-		return $this->_save('PUT',$uri,$content,$callback);
-	}
+sub insert {
+    my ( $this, $uri, $content, $callback ) = @_;
+    return $this->_save( 'POST', $uri, $content, $callback );
+}
 
-	sub delete {
-		my ($this,$uri,$length) = @_;
-		my $req;
-		if($this->override_method eq TRUE){
-			$req = HTTP::Request->new(POST=> $uri);
-			$req->header('X-HTTP-Method-Override'=>'DELETE');
-		}
-		else {
-			$req = HTTP::Request->new(DELETE => $uri);
-		}
-  		$req-> content_type('application/atom+xml; charset=UTF-8');
-		$this->_prepare__request($req);
+sub update {
+    my ( $this, $uri, $content, $callback ) = @_;
+    return $this->_save( 'PUT', $uri, $content, $callback );
+}
 
-		return $this->_request($req);
-	}
+sub delete {
+    my ( $this, $uri, $length ) = @_;
+    my $req;
+    if ( $this->override_method eq TRUE ) {
+        $req = HTTP::Request->new( POST => $uri );
+        $req->header( 'X-HTTP-Method-Override' => 'DELETE' );
+    }
+    else {
+        $req = HTTP::Request->new( DELETE => $uri );
+    }
+    $req->content_type('application/atom+xml; charset=UTF-8');
+    $this->_prepare_request($req);
 
+    return $this->_request($req);
+}
 
 ###PRIVATE###
 
 #methods#
 
-	private _create_ua_base_name => sub {
-		return __PACKAGE__."/".$VERSION;
-	};
+private _create_ua_base_name => sub {
+    return __PACKAGE__ . "/" . $VERSION;
+};
 
-	private _request => sub {
-		my($this,$req)=@_;
+private _request => sub {
+    my ( $this, $req ) = @_;
 
-		if(!$this->{ua}) {
-			my $name = _create_ua_base_name();
-			if($this->auth){
-				$name = $this->auth->source.$name;
-			}
-        	$this->{ua} = _create_ua($name);
-		}
+    if ( !$this->{ua} ) {
+        my $name = _create_ua_base_name();
+        if ( $this->auth ) {
+            $name = $this->auth->source . $name;
+        }
+        $this->{ua} = _create_ua($name);
+    }
 
-        my $res = $this->{ua}->_request($req);		
-    	if ($res->is_success) {
-			return $res->content();
-		}
-		else {
-			die new WebService::GData::Error($res->code,$res->content);
-		}
-	};
+    my $res = $this->{ua}->_request($req);
+    if ( $res->is_success ) {
+        return $res->content();
+    }
+    else {
+        die new WebService::GData::Error( $res->code, $res->content );
+    }
+};
 
-	private _save => sub {
-		my ($this,$method,$uri,$content,$callback) = @_;
-		my $req;
-		if($this->override_method eq TRUE && $method eq 'PUT'){
-			$req = HTTP::Request->new(POST=> $uri);
-			$req->header('X-HTTP-Method-Override'=>'PUT');
-		}
-		else {
-			$req = HTTP::Request->new("$method"=> $uri);
-		}
-  		$req-> content_type('application/atom+xml; charset=UTF-8');
+private _save => sub {
+    my ( $this, $method, $uri, $content, $callback ) = @_;
+    my $req;
+    if ( $this->override_method eq TRUE && $method eq 'PUT' ) {
+        $req = HTTP::Request->new( POST => $uri );
+        $req->header( 'X-HTTP-Method-Override' => 'PUT' );
+    }
+    else {
+        $req = HTTP::Request->new( "$method" => $uri );
+    }
+    $req->content_type('application/atom+xml; charset=UTF-8');
 
+    my $xml_header = XML_HEADER;
+    my $xmlns      = $this->get_namespaces();
 
-		my $xml_header = XML_HEADER;
-		my $xmlns      = $this->get_namespaces();
+    my $xml_content = qq[$xml_header<entry $xmlns>$content</entry>];
 
-		my $xmlcontent = qq[$xml_header<entry $xmlns>$content</entry>];
+    $this->_prepare_request( $req, length($xml_content) );
+    $req->content($xml_content);
+    if ($callback) {
+        &$callback($req);
+    }
 
+    return $this->_request($req);
+};
 
-		$this -> _prepare__request($req,length($xmlcontent));
-    	$req  -> content($xmlcontent);
-		if($callback){
-			&$callback($req);
-		}
-
-		return $this->_request($req);
-	};
-
-	private _prepare__request => sub {
-		my ($this,$req,$length)=@_;
-  		$req->header('GData-Version' => $this->query->get('v'));
-  		$req->header('Content-Length'=> $length) if($length);
-		if($this->auth){
-  		   	$this->auth->set_authorization_headers($this,$req);
-  		   	$this->auth->set_service_headers($this,$req);
-		}		
-	};
+private _prepare_request => sub {
+    my ( $this, $req, $length ) = @_;
+    $req->header( 'GData-Version' => $this->query->get('v') );
+    $req->header( 'Content-Length' => $length ) if ($length);
+    if ( $this->auth ) {
+        $this->auth->set_authorization_headers( $this, $req );
+        $this->auth->set_service_headers( $this, $req );
+    }
+};
 
 #sub#
 
-	private _create_ua => sub {
-		my $name = shift;
-		my $ua = LWP::UserAgent->new;
-		   $ua->agent($name);
-		return $ua;
-	};
+private _create_ua => sub {
+    my $name = shift;
+    my $ua   = LWP::UserAgent->new;
+    $ua->agent($name);
+    return $ua;
+};
 
-	#duck typing has I don't want to enfore inheritance
-	private _is_auth_object_compliant => sub {
-		my $auth=shift;
-		return 1 if($auth && $auth->can('set_authorization_headers') && $auth->can('set_service_headers') && $auth->can('source'));
-		return undef;
-	};
+private _is_object => sub {
+    my $val = shift;
+    eval { $val->can('can'); };
+    return undef if ($@);
+    return 1;
 
-	private _is_query_object_compliant => sub {
-		my $query=shift;
-		return 1 if($query && $query->can('to_query_string') && $query->can('get') && int($query->get('v'))>=GDATA_MINIMUM_VERSION);
-		return undef;
-	};
+};
 
+#duck typing has I don't want to enfore inheritance
+private _is_auth_object_compliant => sub {
+    my $auth = shift;
+    return 1
+      if ( _is_object($auth)
+        && $auth->can('set_authorization_headers')
+        && $auth->can('set_service_headers')
+        && $auth->can('source') );
+    return undef;
+};
 
+private _is_query_object_compliant => sub {
+    my $query = shift;
+    return 1
+      if ( _is_object($query)
+        && $query->can('to_query_string')
+        && $query->can('get')
+        && int( $query->get('v') ) >= GDATA_MINIMUM_VERSION );
+    return undef;
+};
 
-	private _delete_query_string => sub {
-		my $uri = shift;
-		$uri=~s/\?.//;	
-		return $uri;
-	};
+private _delete_query_string => sub {
+    my $uri = shift;
+    $uri =~ s/\?.//;
+    return $uri;
+};
 
 "The earth is blue like an orange.";
 
@@ -291,7 +306,7 @@ You gain access to: get,post,insert,update,delete.
 These methods calls the authentification objects to add extra headers.
 This package should be inherited by services (youtube,analytics,calendar) to offer higher level of abstraction.
 
-Every _request (get,post,insert,update,delete) will throw a L<WebService::GData::Error> in case of failure.
+Every request (get,post,insert,update,delete) will throw a L<WebService::GData::Error> in case of failure.
 It is therefore recommanded to enclose your code in eval blocks to catch and handle the error as you see fit.
 
 The google data based APIs offer different format for the core protocol: atom based, rss based,json based, jsonc based.
@@ -317,7 +332,7 @@ B<Parameters>
 
 =over 
 
-=item C<auth:AuthObject> (optional) - You can set an authorization object like L<WebService::GData::ClientLogin>
+=item C<auth:__AUTH__Object> (optional) - You can set an authorization object like L<WebService::GData::ClientLogin>
 
 =back
 
@@ -363,10 +378,28 @@ The auth object will be used by post/insert/update/delete methods by calling two
 
 =back
 
-These methods will receive the instance calling them and the _request instance.
+These methods will receive the instance calling them and the request instance.
 They shall add any extra headers required to implement their own authentication protocol (ie,ClientLogin,OAuth,SubAuth).
 If the object can not handle the above methods it will not be set.
 
+B<Parameters>
+
+=over
+
+=item C<none> - use as a getter
+
+=item C<auth:Object> - use as a setter: a auth object defining the necessary methods.
+
+=back
+
+B<Returns> 
+
+=over 
+
+=item C<auth:Object> in a setter/getter context.
+
+=back
+
 Example:
 
     use WebService::GData::Base;
@@ -417,9 +450,7 @@ B<Returns>
 
 =over 
 
-=item C<void> in a setter context. 
-
-=item C<query:Object> in a getter context.
+=item C<query:Object> in a setter/getter context.
 
 =back
 
@@ -501,263 +532,6 @@ Example:
 	   
 =back
 
-	
-=head2 READ METHODS
-
-=head3 get
-
-=over
-
-Get the content of a feed in any format. If the format is json or jsonc, it will send back a perl object.
-If an auth object is specified, it will call the required methods to set the authentication headers.
-It will also set the 'GData-Version' header by calling $this->query->get('v');
-You should put the code in a eval { ... }; block to catch any error.
-
-B<Parameters>
-
-=over 
-
-=item C<url:Scalar> - an url to fetch that do not contain any query string.
-
-Query string will be removed before sending the _request.
-
-=back
-
-B<Returns> 
-
-=over 
-
-=item C<response:Object|Scalar> - a perl object if it is a json or jsonc _request else the raw content.
-
-=back
-
-B<Throws> 
-
-=over 
-
-=item L<WebService::GData::Error> if it fails to reach the contents.
-
-=back
-
-Example:
-
-    use WebService::GData::Base;
-	
-    my $base   = new WebService::GData::Base();
-    
-    $base->get('http://gdata.youtube.com/feeds/api/standardfeeds/top_rated');
-	
-    #is in fact calling:
-    #http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=json&prettyprint=false&strict=true&v=2
-
-    #the query string will be erased...
-	
-    $base->get('http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=atom');
-	
-    #is in fact calling:
-    #http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=json&prettyprint=false&strict=true&v=2
-
-=back
-
-=head2 WRITE METHODS
-
-=head3 post
-
-=over
-
-Post data to an url with application/x-www-form-urlencoded content type.
-An auth object must be specified. it will call the required methods to set the authentication headers.
-It will also set the 'GData-Version' header by calling $this->query->get('v');
-You should put the code in a eval { ... }; block to catch any error.
-
-B<Parameters>
-
-=over
-
-=item C<url:Scalar> - the url to query
-
-=item C<content:Scalar|Binary> - the content to post
-
-=back
-
-B<Returns> 
-
-=over 
-
-=item C<response:Scalar> - the response to the query in case of success.
-
-=back
-
-B<Throws> 
-
-=over 
-
-=item L<WebService::GData::Error> if it fails to reach the contents.
-
-=back
-
-
-Example:
-
-    use WebService::GData::Base;
-	
-    #you must be authorized to do any write actions.
-    my $base   = new WebService::GData::Base(auth=>...);
-    
-    #create a new entry with application/x-www-form-urlencoded content-type
-    my $ret = $base->post($url,$content);
-	
-=back
-
-=head3 insert
-
-=over
-
-Insert data to an url with application/atom+xml; charset=UTF-8 content type (POST).
-An auth object must be specified. it will call the required methods to set the authentication headers.
-It will also set the 'GData-Version' header by calling $this->query->get('v');
-You should put the code in a eval { ... }; block to catch any error.
-
-B<Parameters>
-
-=over
-
-=item C<url:Scalar> - the url to query
-
-=item C<content:Scalar> - the content to post in xml format will be decorated with:
-
-    <?xml version="1.0" encoding="UTF-8"?><entry $xmlns>$content</entry>
-
-where $xmlns is the result of C<get_namespace>.
-
-=back
-
-B<Returns> 
-
-=over
-
-=item C<response:Scalar> - the response to the query in case of success.
-
-=back
-
-B<Throws> 
-
-=over 
-
-=item L<WebService::GData::Error> if it fails to reach the contents.
-
-=back
-
-Example:
-
-    use WebService::GData::Base;
-	
-    #you must be authorized to do any write actions.
-    my $base   = new WebService::GData::Base(auth=>...);
-    
-    #create a new entry with application/atom+xml; charset=UTF-8 content-type
-    my $ret = $base->insert($url,$content);
-
-=back
-
-=head3 update
-
-=over
-
-Update data to an url with application/atom+xml; charset=UTF-8 content type (PUT).
-An auth object must be specified. it will call the required methods to set the authentication headers.
-It will also set the 'GData-Version' header by calling $this->query->get('v');
-You should put the code in a eval { ... }; block to catch any error.
-
-B<Parameters>
-
-=over
-
-=item C<url:Scalar> - the url to query
-
-=item C<content:Scalar> - the content to put in xml format will be decorated with:
-
-    <?xml version="1.0" encoding="UTF-8"?><entry $xmlns>$content</entry>
-
-where $xmlns is the result of C<get_namespace>.
-
-=back
-
-B<Returns> 
-
-=over 
-
-=item C<response:Scalar> - the response to the query in case of success.
-
-=back
-
-B<Throws> 
-
-=over
-
-=item L<WebService::GData::Error> if it fails to reach the contents.
-
-=back
-
-Example:
-
-    use WebService::GData::Base;
-	
-    #you must be authorized to do any write actions.
-    my $base   = new WebService::GData::Base(auth=>...);
-    
-    #create a new entry with application/atom+xml; charset=UTF-8 content-type
-    my $ret = $base->upate($url,$content);
-	
-=back
-
-=head3 delete
-
-=over
-
-Delete data from an url with application/atom+xml; charset=UTF-8 content type (DELETE).
-An auth object must be specified. it will call the required methods to set the authentication headers.
-It will also set the 'GData-Version' header by calling $this->query->get('v');
-You should put the code in a eval { ... }; block to catch any error.
-
-B<Parameters>
-
-=over
-
-=item C<url:Scalar> - the url to query
-
-=back
-
-B<Returns> 
-
-=over
-
-=item C<response:Scalar> - the response to the query in case of success.
-
-=back
-
-B<Throws> 
-
-=over
-
-=item L<WebService::GData::Error> if it fails to reach the contents.
-
-=back
-
-
-Example:
-
-    use WebService::GData::Base;
-	
-    #you must be authorized to do any write actions.
-    my $base   = new WebService::GData::Base(auth=>...);
-    
-    #create a new entry with application/atom+xml; charset=UTF-8 content-type
-    my $ret = $base->delete($url);
-	
-=back
-
-
 =head3 add_namespace
 
 =over
@@ -837,11 +611,12 @@ Example:
 	
     my $namespaces = $base->get_namespace();
 
-    #$namespaces = xmlns="http://www.w3.org/2005/Atom" xmlns:media='http://search.yahoo.com/mrss/' xmlns:gd="http://schemas.google.com/g/2005"
+    #$namespaces = xmlns="http://www.w3.org/2005/Atom" xmlns:media='http://search.yahoo.com/mrss/'+
+    # xmlns:gd="http://schemas.google.com/g/2005"
 	
 =back
 
-=head3 clean_namespace 
+=head3 clean_namespaces 
 
 =over
 
@@ -877,19 +652,272 @@ Example:
 	
     my $namespaces = $base->get_namespace();
 
-    #$namespaces = xmlns="http://www.w3.org/2005/Atom" xmlns:media='http://search.yahoo.com/mrss/' xmlns:gd="http://schemas.google.com/g/2005"
+    #$namespaces = xmlns="http://www.w3.org/2005/Atom" xmlns:media='http://search.yahoo.com/mrss/'+
+    # xmlns:gd="http://schemas.google.com/g/2005"
 	
-    $base->clean_namespace();
+    $base->clean_namespaces();
     my $namespaces = $base->get_namespace();#""
 	
 =back
 
 
+	
+=head2 READ METHODS
+
+=head3 get
+
+=over
+
+Get the content of a feed in any format. If the format is json or jsonc, it will send back a perl object.
+If an auth object is specified, it will call the required methods to set the authentication headers.
+It will also set the 'GData-Version' header by calling $this->query->get('v');
+You should put the code in a eval { ... }; block to catch any error.
+
+B<Parameters>
+
+=over 
+
+=item C<url:Scalar> - an url to fetch that do not contain any query string.
+
+Query string will be removed before sending the request.
+
+=back
+
+B<Returns> 
+
+=over 
+
+=item C<response:Object|Scalar> - a perl object if it is a json or jsonc request else the raw content.
+
+=back
+
+B<Throws> 
+
+=over 
+
+=item L<WebService::GData::Error> if it fails to reach the contents.
+
+=back
+
+Example:
+
+    use WebService::GData::Base;
+	
+    my $base   = new WebService::GData::Base();
+    
+    $base->get('http://gdata.youtube.com/feeds/api/standardfeeds/top_rated');
+	
+    #is in fact calling:
+    #http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=json&prettyprint=false&strict=true&v=2
+
+    #the query string will be erased...
+	
+    $base->get('http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=atom');
+	
+    #is in fact calling:
+    #http://gdata.youtube.com/feeds/api/standardfeeds/top_rated?alt=json&prettyprint=false&strict=true&v=2
+
+=back
+
+=head2 WRITE METHODS
+
+All the following methods will set the 'GData-Version' header by calling $this->query->get('v');
+You should put the code in a eval { ... }; block to catch any error these methods may throw.
+
+=head3 post
+
+=over
+
+Post data to an url with application/x-www-form-urlencoded content type.
+An auth object must be specified. it will call the required methods to set the authentication headers.
+
+B<Parameters>
+
+=over
+
+=item C<url:Scalar> - the url to query
+
+=item C<content:Scalar|Binary> - the content to post
+
+=back
+
+B<Returns> 
+
+=over 
+
+=item C<response:Scalar> - the response to the query in case of success.
+
+=back
+
+B<Throws> 
+
+=over 
+
+=item L<WebService::GData::Error> if it fails to reach the contents.
+
+=back
+
+
+Example:
+
+    use WebService::GData::Base;
+	
+    #you must be authorized to do any write actions.
+    my $base   = new WebService::GData::Base(auth=>...);
+    
+    #create a new entry with application/x-www-form-urlencoded content-type
+    my $ret = $base->post($url,$content);
+	
+=back
+
+=head3 insert
+
+=over
+
+Insert data to an url with application/atom+xml; charset=UTF-8 content type (POST).
+An auth object must be specified. it will call the required methods to set the authentication headers.
+
+
+B<Parameters>
+
+=over
+
+=item C<url:Scalar> - the url to query
+
+=item C<content:Scalar> - the content to post in xml format will be decorated with:
+
+    <?xml version="1.0" encoding="UTF-8"?><entry $xmlns>$content</entry>
+
+where $xmlns is the result of C<get_namespace>.
+
+=back
+
+B<Returns> 
+
+=over
+
+=item C<response:Scalar> - the response to the query in case of success.
+
+=back
+
+B<Throws> 
+
+=over 
+
+=item L<WebService::GData::Error> if it fails to reach the contents.
+
+=back
+
+Example:
+
+    use WebService::GData::Base;
+	
+    #you must be authorized to do any write actions.
+    my $base   = new WebService::GData::Base(auth=>...);
+    
+    #create a new entry with application/atom+xml; charset=UTF-8 content-type
+    my $ret = $base->insert($url,$content);
+
+=back
+
+=head3 update
+
+=over
+
+Update data to an url with application/atom+xml; charset=UTF-8 content type (PUT).
+An auth object must be specified. it will call the required methods to set the authentication headers.
+
+B<Parameters>
+
+=over
+
+=item C<url:Scalar> - the url to query
+
+=item C<content:Scalar> - the content to put in xml format will be decorated with:
+
+    <?xml version="1.0" encoding="UTF-8"?><entry $xmlns>$content</entry>
+
+where $xmlns is the result of C<get_namespace>.
+
+=back
+
+B<Returns> 
+
+=over 
+
+=item C<response:Scalar> - the response to the query in case of success.
+
+=back
+
+B<Throws> 
+
+=over
+
+=item L<WebService::GData::Error> if it fails to reach the contents.
+
+=back
+
+Example:
+
+    use WebService::GData::Base;
+	
+    #you must be authorized to do any write actions.
+    my $base   = new WebService::GData::Base(auth=>...);
+    
+    #create a new entry with application/atom+xml; charset=UTF-8 content-type
+    my $ret = $base->upate($url,$content);
+	
+=back
+
+=head3 delete
+
+=over
+
+Delete data from an url with application/atom+xml; charset=UTF-8 content type (DELETE).
+
+B<Parameters>
+
+=over
+
+=item C<url:Scalar> - the url to query
+
+=back
+
+B<Returns> 
+
+=over
+
+=item C<response:Scalar> - the response to the query in case of success.
+
+=back
+
+B<Throws> 
+
+=over
+
+=item L<WebService::GData::Error> if it fails to reach the contents.
+
+=back
+
+
+Example:
+
+    use WebService::GData::Base;
+	
+    #you must be authorized to do any write actions.
+    my $base   = new WebService::GData::Base(auth=>...);
+    
+    #create a new entry with application/atom+xml; charset=UTF-8 content-type
+    my $ret = $base->delete($url);
+	
+=back
+
+
 =head2  HANDLING ERRORS
 
 Google data APIs relies on querying remote urls on particular services.
 
-Some of these services limits the number of _request with quotas and may return an error code in such a case.
+Some of these services limits the number of request with quotas and may return an error code in such a case.
 
 All queries that fail will throw (die) a L<WebService::GData::Error> object. 
 
@@ -941,4 +969,4 @@ shiriru E<lt>shirirulestheworld[arobas]gmail.comE<gt>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
-=cut
\ No newline at end of file
+=cut
